@@ -1,44 +1,35 @@
 package Error::Hierarchy::Mixin;
-
-# $Id: Mixin.pm 13640 2007-10-16 13:41:51Z gr $
-
 use strict;
 use warnings;
 use Error;    # to get $Error::Depth
-
-
-our $VERSION = '0.04';
-
+our $VERSION = '0.07';
 
 BEGIN {
     *CORE::GLOBAL::die = sub (@) {
+
         # Error.pm die()s as well, but we don't want an endless recursion.
-        CORE::die(@_) if (caller)[0] eq 'Error';
-        local $Error::Depth = $Error::Depth + 1;  # skip this level
+        CORE::die(@_) if (caller)[0] eq 'Error' || ref $_[0];
+        local $Error::Depth = $Error::Depth + 1;    # skip this level
         throw Error::Hierarchy::Internal::CustomMessage(
-            custom_message => join(' ', @_),
-        );
+            custom_message => join(' ', @_),);
     };
 }
 
-
 # Any class that wants to throw an exception can simply use or inherit from
 # this module and call 'throw Error::Whatever' without having to 'require' it
 # first. By putting the throw() method in UNIVERSAL:: we catch method calls on
 # exception classes that haven't been loaded yet. We load the class, then
 # throw the exception.
-
 sub UNIVERSAL::throw {
+
     # use Data::Dumper; print Dumper \@_; exit if ++(our $cnt) > 5;
     my ($exception_class, %args) = @_;
 
     # need to modify $Error::Depth (see Error.pm) to make certain parts
     # of the call stack invisible to caller()
     # +1 to make UNIVERSAL::throw() invisible
-
     # in case it wasn't loaded; to make sure $Error::Depth isn't undef
     require Error;
-
     local $Error::Depth = $Error::Depth + 1;
     eval "require $exception_class";
     CORE::die($@) if $@;
@@ -46,27 +37,20 @@ sub UNIVERSAL::throw {
 }
 
 # Similar reasoning for record().
-
 sub UNIVERSAL::record {
     my ($exception_class, %args) = @_;
 
     # need to modify $Error::Depth (see Error.pm) to make certain parts
     # of the call stack invisible to caller()
     # +1 to make UNIVERSAL::record() invisible
-
     # in case it wasn't loaded; to make sure $Error::Depth isn't undef
     require Error;
-
     local $Error::Depth = $Error::Depth + 1;
     eval "require $exception_class";
     CORE::die $@ if $@;
     $exception_class->record(%args);
 }
-
-
 1;
-
-
 __END__
 
 =head1 NAME
@@ -78,7 +62,7 @@ Error::Hierarchy::Mixin - provides often-used exception-related methods
   package MyClass;
   use Error::Hierarchy::Mixin;
 
-  Some::Exception->throw(...);
+  Some::Exception->throw(foo => 'bar');
 
 =head1 DESCRIPTION
 
@@ -93,31 +77,27 @@ C<die()>, use C<CORE::die()> instead.
 
 =over 4
 
-=item throw
+=item C<throw>
 
 Takes an exception class name (a string) and a hash of arguments. Loads the
-exception class, constructs an exception object, passes it the argumments and
+exception class, constructs an exception object, passes it the arguments and
 throws it by calling the exception object's C<throw()> method. It populates
 the UNIVERSAL namespace, so all packages get this ability.
 
-=item record
+=item C<record>
 
 Like C<throw()>, but records the exception using the exception object's
 C<record()> method.
 
 =back
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else, please
-use the C<errorhierarchy> tag.
+Error::Hierarchy::Mixin inherits from .
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-error-hierarchy@rt.cpan.org>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -127,19 +107,18 @@ See perlmodinstall for information and options on installing Perl modules.
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN site
-near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2009 by the authors.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
-
